===============
LibRapid Extent
===============

An extent (basic_extent) stores the physical size of an NDarray, and
can be used to iterate over an array if needed.

.. WARNING::
    The ability to iterate over an array is currently not available,
    and iterating using the extent object is very tedious. This **will**
    be changed in the future.
